complete -c sile -s b -l backend -d 'Specify the output backend' -r
complete -c sile -s c -l class -d 'Override the default or specified document class' -r
complete -c sile -s d -l debug -d 'Show debug information for tagged aspects of SILE’s operation' -r
complete -c sile -s e -l evaluate -d 'Evaluate Lua expression before processing input' -r
complete -c sile -s E -l evaluate-after -d 'Evaluate Lua expression after processing input' -r
complete -c sile -s f -l fontmanager -d 'Specify which font manager to use' -r
complete -c sile -l luarocks-tree -d 'Add a path to the list of LuaRocks trees searched for modules' -r -F
complete -c sile -s m -l makedeps -d 'Generate a Makefile format list of dependencies and white them to a file' -r -F
complete -c sile -s o -l output -d 'Explicitly set the output file name' -r -F
complete -c sile -s O -l option -d 'Set or override document class options' -r
complete -c sile -s p -l preamble -d 'Include the contents of a SIL, XML, or other resource file before the input document content' -r -F
complete -c sile -s P -l postamble -d 'Include the contents of a SIL, XML, or other resource file after the input document content' -r -F
complete -c sile -s u -l use -d 'Load and initialize a class, inputter, shaper, or other module before processing the main input' -r
complete -c sile -s q -l quiet -d 'Suppress warnings and informational messages during processing'
complete -c sile -s t -l traceback -d 'Display detailed location trace on errors and warnings'
complete -c sile -s h -l help -d 'Print help (see more with \'--help\')'
